# Module: cdf_idf_default

This module configures a default identity provider for a project. It is meant to be used as part of
project implementation. This module should be swapped out for a module that configures the
specific identity provider for the project.
